function plotSin4(a,b,n)
% usage: plotSin4(a,b,n)
% a = starting x value
% b = ending x value
% n = number of segments between a and b

%defien the domain from input values
x = linspace(a,b,n);

% define the sin function
f = sin(x);

% and plot
plot(x,f)